# LTP tests

This suite contains LTP tests that do not use filesystem syscalls. The other tests are located [here](../ltp_fs)

## running tests

To run the LTP tests against the ext2fs/hostfs/ramfs, do this:

```bash
make alltests FS=ext2fs
```

The tests have been segregated into files based on their state (running/failing/how are they failing). The following key applies -

ALL TESTS

1. [tests_alltests.txt](tests_alltests.txt): All the tests in ltp that we have (pass + fail)

PASSING

1. [fs-type_tests_passed.txt](ext2fs_tests_passed.txt): All tests that pass using a particular fs (ramfs/ext2fs/hostfs)
2. [fs-type_fs_tests_passed.txt](ext2fs_fs_tests_passed.txt): All filesystem syscall tests using a particular fs that pass

FAILING

1. [fs-type_tests_unhandled_syscalls.txt](ext2fs_tests_unhandled_syscalls.txt): Tests that fail due to an unimplemented syscall in mystikos.
2. [fs-type_tests_other_errors.txt](ext2fs_tests_other_errors.txt): Tests that fail due to errors like invalid return value, etc.

## TEST MATRIX

| TEST | EXT2FS | HOSTFS | RAMFS |
| --- | --- | --- | --- |
| /ltp/testcases/kernel/syscalls/abort/abort01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/accept/accept01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/accept/accept02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/accept4/accept4_01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/access/access01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/access/access02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/access/access03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/access/access04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/acct/acct01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/acct/acct02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/acct/acct02_helper | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/add_key/add_key01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/add_key/add_key02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/add_key/add_key03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/add_key/add_key04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/add_key/add_key05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/adjtimex/adjtimex01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/adjtimex/adjtimex02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/adjtimex/adjtimex03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/alarm/alarm02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/alarm/alarm03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/alarm/alarm05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/alarm/alarm06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/alarm/alarm07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bind/bind01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bind/bind02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bind/bind03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bind/bind04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bind/bind05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bind/bind06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bpf/bpf_map01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bpf/bpf_prog01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bpf/bpf_prog02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bpf/bpf_prog03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/bpf/bpf_prog04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/brk/brk01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/brk/brk02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/cacheflush/cacheflush01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/capget/capget01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/capget/capget02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/capset/capset01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/capset/capset02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/capset/capset03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/capset/capset04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chdir/chdir01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chdir/chdir04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chmod/chmod01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chmod/chmod02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chmod/chmod03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chmod/chmod04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chmod/chmod05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chmod/chmod06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chmod/chmod07 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chown/chown01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chown/chown01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chown/chown02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chown/chown02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chown/chown03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chown/chown03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chown/chown04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chown/chown04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chown/chown05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/chown/chown05_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chroot/chroot01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chroot/chroot02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chroot/chroot03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/chroot/chroot04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_adjtime/clock_adjtime01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_adjtime/clock_adjtime02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_getres/clock_getres01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_gettime/clock_gettime01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/clock_gettime/clock_gettime02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_gettime/clock_gettime03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_gettime/clock_gettime04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_gettime/leapsec01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_nanosleep/clock_nanosleep01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_nanosleep/clock_nanosleep02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_nanosleep/clock_nanosleep03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_nanosleep/clock_nanosleep04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_settime/clock_settime01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_settime/clock_settime02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clock_settime/clock_settime03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone/clone01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone/clone02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone/clone03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone/clone04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/clone/clone05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone/clone06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone/clone07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone/clone08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone/clone09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone3/clone301 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/clone3/clone302 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/close/close01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/close/close02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/close/close08 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/close_range/close_range01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/close_range/close_range02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/cma/process_vm01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/cma/process_vm_readv02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/cma/process_vm_readv03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/cma/process_vm_writev02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/connect/connect01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/connect/connect02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/copy_file_range/copy_file_range01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/copy_file_range/copy_file_range02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/copy_file_range/copy_file_range03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/creat/creat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/creat/creat03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/creat/creat04 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/creat/creat05 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/creat/creat06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/creat/creat07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/creat/creat07_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/creat/creat08 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/delete_module/delete_module01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/delete_module/delete_module02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/delete_module/delete_module03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/dup/dup01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/dup/dup02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/dup/dup03 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/dup/dup04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/dup/dup05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/dup/dup06 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/dup/dup07 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/dup2/dup201 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/dup2/dup202 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/dup2/dup203 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/dup2/dup204 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/dup2/dup205 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/dup3/dup3_01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/dup3/dup3_02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/epoll_create1/epoll_create1_01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/epoll_ctl/epoll_ctl01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/epoll_ctl/epoll_ctl02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/epoll_pwait/epoll_pwait01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/epoll_wait/epoll_wait01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/epoll_wait/epoll_wait02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/epoll_wait/epoll_wait03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/eventfd/eventfd01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/eventfd2/eventfd2_01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/eventfd2/eventfd2_02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/eventfd2/eventfd2_03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execl/execl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execl/execl01_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execle/execle01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execle/execle01_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execlp/execlp01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execlp/execlp01_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execv/execv01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execv/execv01_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execve/execve01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execve/execve01_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execve/execve02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execve/execve03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execve/execve04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execve/execve05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execve/execve_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execveat/execveat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execveat/execveat02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execveat/execveat03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execveat/execveat_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execveat/execveat_errno | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execvp/execvp01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/execvp/execvp01_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/exit/exit01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/exit/exit02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/exit_group/exit_group01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/faccessat/faccessat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fadvise/posix_fadvise01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fadvise/posix_fadvise01_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fadvise/posix_fadvise02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fadvise/posix_fadvise02_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fadvise/posix_fadvise03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fadvise/posix_fadvise03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fadvise/posix_fadvise04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fadvise/posix_fadvise04_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fallocate/fallocate01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fallocate/fallocate02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fallocate/fallocate03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fallocate/fallocate04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fallocate/fallocate05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fallocate/fallocate06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify11 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify13 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify14 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify15 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fanotify/fanotify_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchdir/fchdir01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchdir/fchdir02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchdir/fchdir03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchmod/fchmod01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchmod/fchmod02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchmod/fchmod03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchmod/fchmod04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchmod/fchmod05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchmod/fchmod06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchmodat/fchmodat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchown/fchown01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchown/fchown01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchown/fchown02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchown/fchown02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchown/fchown03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchown/fchown03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchown/fchown04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchown/fchown04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchown/fchown05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchown/fchown05_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fchownat/fchownat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fchownat/fchownat02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl01_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl02_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl03_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl04_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl05_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl06_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl07_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl08 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl08_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl09_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl10 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl10_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl11 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl11_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl12_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl13 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl13_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl14 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl14_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl15 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl15_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl16_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl17 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl17_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl18 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl18_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl19 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl19_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl20 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl20_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl21 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl21_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl22 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl22_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl23 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl23_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl24 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl24_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl25 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl25_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl26 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl26_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl27 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl27_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl28 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl28_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl29 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl29_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl30 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl30_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl31 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl31_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl32 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl32_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl33 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl33_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl34 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl34_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl35 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl35_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl36 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl36_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl37 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl37_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl38 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fcntl/fcntl38_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fdatasync/fdatasync01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fdatasync/fdatasync02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fdatasync/fdatasync03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fgetxattr/fgetxattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fgetxattr/fgetxattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fgetxattr/fgetxattr03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/finit_module/finit_module01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/finit_module/finit_module02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/flistxattr/flistxattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/flistxattr/flistxattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/flistxattr/flistxattr03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/flock/flock01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/flock/flock02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/flock/flock03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/flock/flock04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/flock/flock06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fork/fork01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fork/fork02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fork/fork03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fork/fork04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fork/fork05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fork/fork06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fork/fork07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fork/fork08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fork/fork09 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/fork/fork10 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/fork/fork11 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fork/fork12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fork/fork13 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fork/fork14 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fpathconf/fpathconf01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fremovexattr/fremovexattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fremovexattr/fremovexattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsconfig/fsconfig01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsconfig/fsconfig02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsetxattr/fsetxattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsetxattr/fsetxattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsmount/fsmount01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsmount/fsmount02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsopen/fsopen01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsopen/fsopen02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fspick/fspick01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fspick/fspick02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fstat/fstat02 | 0 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fstat/fstat02_64 | 0 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fstat/fstat03 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/fstat/fstat03_64 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/fstatat/fstatat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fstatfs/fstatfs01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fstatfs/fstatfs01_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fstatfs/fstatfs02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fstatfs/fstatfs02_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsync/fsync01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsync/fsync02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/fsync/fsync03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/fsync/fsync04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ftruncate/ftruncate01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/ftruncate/ftruncate01_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/ftruncate/ftruncate03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ftruncate/ftruncate03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ftruncate/ftruncate04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ftruncate/ftruncate04_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futex/futex_cmp_requeue01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futex/futex_cmp_requeue02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futex/futex_wait01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/futex/futex_wait02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/futex/futex_wait03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/futex/futex_wait04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/futex/futex_wait05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futex/futex_wait_bitset01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futex/futex_wake01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futex/futex_wake02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futex/futex_wake03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futex/futex_wake04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/futimesat/futimesat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/get_mempolicy/get_mempolicy01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/get_mempolicy/get_mempolicy02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/get_robust_list/get_robust_list01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getcpu/getcpu01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getcwd/getcwd01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getcwd/getcwd02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getcwd/getcwd03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getcwd/getcwd04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getdents/getdents01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getdents/getdents02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getdomainname/getdomainname01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getdtablesize/getdtablesize01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getegid/getegid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getegid/getegid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getegid/getegid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getegid/getegid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/geteuid/geteuid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/geteuid/geteuid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/geteuid/geteuid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/geteuid/geteuid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getgid/getgid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getgid/getgid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getgid/getgid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getgid/getgid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getgroups/getgroups01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getgroups/getgroups01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getgroups/getgroups03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getgroups/getgroups03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/gethostbyname_r/gethostbyname_r01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/gethostid/gethostid01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/gethostname/gethostname01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getitimer/getitimer01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getitimer/getitimer02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getitimer/getitimer03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getpagesize/getpagesize01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getpeername/getpeername01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getpgid/getpgid01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getpgid/getpgid02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getpgrp/getpgrp01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getpid/getpid01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getpid/getpid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getppid/getppid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getppid/getppid02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getpriority/getpriority01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getpriority/getpriority02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrandom/getrandom01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getrandom/getrandom02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getrandom/getrandom03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getrandom/getrandom04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getresgid/getresgid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getresgid/getresgid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getresgid/getresgid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getresgid/getresgid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getresgid/getresgid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getresgid/getresgid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getresuid/getresuid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getresuid/getresuid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getresuid/getresuid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getresuid/getresuid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getresuid/getresuid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getresuid/getresuid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrlimit/getrlimit01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrlimit/getrlimit02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrlimit/getrlimit03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrusage/getrusage01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrusage/getrusage02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrusage/getrusage03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrusage/getrusage03_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getrusage/getrusage04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getsid/getsid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getsid/getsid02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getsockname/getsockname01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getsockopt/getsockopt01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getsockopt/getsockopt02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/gettid/gettid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/gettimeofday/gettimeofday01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/gettimeofday/gettimeofday02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getuid/getuid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getuid/getuid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getuid/getuid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/getuid/getuid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getxattr/getxattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getxattr/getxattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getxattr/getxattr03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getxattr/getxattr04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/getxattr/getxattr05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/init_module/init_module01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/init_module/init_module02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify06 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/inotify/inotify07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify/inotify10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify_init/inotify_init1_01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/inotify_init/inotify_init1_02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_cancel/io_cancel01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_destroy/io_destroy01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_getevents/io_getevents01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_pgetevents/io_pgetevents01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_pgetevents/io_pgetevents02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_setup/io_setup01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_submit/io_submit01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_uring/io_uring01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/io_uring/io_uring02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_loop01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_loop02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_loop03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_loop04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_loop05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_loop06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_loop07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_ns01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_ns02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_ns03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_ns04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_ns05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_ns06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_ns07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/ioctl_sg01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioctl/test_ioctl | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioperm/ioperm01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioperm/ioperm02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/iopl/iopl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/iopl/iopl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioprio/ioprio_get01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioprio/ioprio_set01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioprio/ioprio_set02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ioprio/ioprio_set03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgctl/msgctl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgctl/msgctl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgctl/msgctl03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgctl/msgctl04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgctl/msgctl05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgctl/msgctl06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgctl/msgctl12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgget/msgget01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgget/msgget02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgget/msgget03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgget/msgget04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgget/msgget05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgrcv/msgrcv01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgrcv/msgrcv02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgrcv/msgrcv03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgrcv/msgrcv05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgrcv/msgrcv06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgrcv/msgrcv07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgrcv/msgrcv08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgsnd/msgsnd01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgsnd/msgsnd02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgsnd/msgsnd05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgsnd/msgsnd06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgstress/msgstress01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgstress/msgstress02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgstress/msgstress03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/msgstress/msgstress04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semctl/semctl09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semget/semget01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semget/semget02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semget/semget03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semget/semget05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semget/semget06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semop/semop01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semop/semop02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/semop/semop03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmat/shmat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmat/shmat02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmat/shmat03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmctl/shmctl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmctl/shmctl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmctl/shmctl03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmctl/shmctl04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmctl/shmctl05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmctl/shmctl06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmctl/shmctl07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmctl/shmctl08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmdt/shmdt01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmdt/shmdt02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmget/shmget01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmget/shmget02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmget/shmget03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmget/shmget04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ipc/shmget/shmget05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kcmp/kcmp01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kcmp/kcmp02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kcmp/kcmp03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/keyctl/keyctl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/keyctl/keyctl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/keyctl/keyctl03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/keyctl/keyctl04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/keyctl/keyctl05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/keyctl/keyctl06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/keyctl/keyctl07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/keyctl/keyctl08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill11 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/kill/kill12 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/lchown/lchown01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/lchown/lchown01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/lchown/lchown02 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/lchown/lchown02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/lchown/lchown03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/lchown/lchown03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/lgetxattr/lgetxattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/lgetxattr/lgetxattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/link/link02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/link/link03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/link/link04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/link/link05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/link/link06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/link/link07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/link/link08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/linkat/linkat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/linkat/linkat02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/listen/listen01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/listxattr/listxattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/listxattr/listxattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/listxattr/listxattr03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/llistxattr/llistxattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/llistxattr/llistxattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/llistxattr/llistxattr03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/llseek/llseek01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/llseek/llseek02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/llseek/llseek03 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/lremovexattr/lremovexattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/lseek/lseek01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/lseek/lseek02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/lseek/lseek07 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/lseek/lseek11 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/lstat/lstat01 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/lstat/lstat01_64 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/lstat/lstat02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/lstat/lstat02_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/madvise/madvise01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/madvise/madvise02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/madvise/madvise05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/madvise/madvise06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/madvise/madvise07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/madvise/madvise08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/madvise/madvise09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/madvise/madvise10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mallinfo/mallinfo01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mallinfo/mallinfo02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mallopt/mallopt01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mbind/mbind01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mbind/mbind02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mbind/mbind03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mbind/mbind04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/membarrier/membarrier01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/memcmp/memcmp01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/memcpy/memcpy01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/memfd_create/memfd_create01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/memfd_create/memfd_create02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/memfd_create/memfd_create03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/memfd_create/memfd_create04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/memmap/mem03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/memset/memset01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/migrate_pages/migrate_pages01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/migrate_pages/migrate_pages02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/migrate_pages/migrate_pages03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mincore/mincore01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mincore/mincore02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mincore/mincore03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mincore/mincore04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mkdir/mkdir02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mkdir/mkdir03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mkdir/mkdir04 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/mkdir/mkdir05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mkdir/mkdir09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mkdirat/mkdirat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mkdirat/mkdirat02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknod/mknod09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknodat/mknodat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mknodat/mknodat02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mlock/mlock01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mlock/mlock02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mlock/mlock03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mlock/mlock04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mlock2/mlock201 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mlock2/mlock202 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mlock2/mlock203 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mlockall/mlockall01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mlockall/mlockall02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mlockall/mlockall03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mmap/mmap001 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/mmap/mmap01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap06 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap07 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap08 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap09 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mmap/mmap11 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mmap/mmap13 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mmap/mmap14 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mmap/mmap15 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mmap/mmap16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mmap/mmap17 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mmap/mmap18 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/modify_ldt/modify_ldt01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/modify_ldt/modify_ldt02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/modify_ldt/modify_ldt03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mount/mount01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mount/mount02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mount/mount03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mount/mount03_setuid_test | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mount/mount04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mount/mount05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mount/mount06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_mount/move_mount01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_mount/move_mount02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages11 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/move_pages/move_pages12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mprotect/mprotect01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mprotect/mprotect02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mprotect/mprotect03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mprotect/mprotect04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mq_notify/mq_notify01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mq_notify/mq_notify02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mq_open/mq_open01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mq_timedreceive/mq_timedreceive01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mq_timedsend/mq_timedsend01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mq_unlink/mq_unlink01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mremap/mremap01 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/mremap/mremap02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/mremap/mremap03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mremap/mremap04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/mremap/mremap05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/msync/msync01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/msync/msync02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/msync/msync03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/msync/msync04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/munlock/munlock01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/munlock/munlock02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/munlockall/munlockall01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/munmap/munmap01 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/munmap/munmap02 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/munmap/munmap03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/name_to_handle_at/name_to_handle_at01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/name_to_handle_at/name_to_handle_at02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/nanosleep/nanosleep01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/nanosleep/nanosleep02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/nanosleep/nanosleep04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/newuname/newuname01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/nftw/nftw01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/nftw/nftw6401 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/nice/nice01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/nice/nice02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/nice/nice03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/nice/nice04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open/open01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/open/open02 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/open/open03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/open/open04 | 1 | 0 | 1 |
| /ltp/testcases/kernel/syscalls/open/open05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open/open06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open/open07 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/open/open08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open/open09 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/open/open10 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/open/open11 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open/open12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open/open12_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open/open13 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open/open14 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open_by_handle_at/open_by_handle_at01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open_by_handle_at/open_by_handle_at02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open_tree/open_tree01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/open_tree/open_tree02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/openat/openat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/openat/openat02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/openat/openat02_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/openat/openat03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/openat2/openat201 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/openat2/openat202 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/openat2/openat203 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pathconf/pathconf01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pause/pause01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pause/pause02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pause/pause03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/perf_event_open/perf_event_open01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/perf_event_open/perf_event_open02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/personality/personality01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/personality/personality02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pidfd_open/pidfd_open01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pidfd_open/pidfd_open02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pidfd_open/pidfd_open03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pidfd_send_signal/pidfd_send_signal01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pidfd_send_signal/pidfd_send_signal02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pidfd_send_signal/pidfd_send_signal03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe/pipe01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pipe/pipe02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe/pipe03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pipe/pipe04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pipe/pipe05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe/pipe06 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pipe/pipe07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe/pipe08 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pipe/pipe09 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pipe/pipe10 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pipe/pipe11 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe/pipe12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe/pipe13 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe2/pipe2_01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pipe2/pipe2_02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe2/pipe2_02_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pipe2/pipe2_04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pivot_root/pivot_root01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pkeys/pkey01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/poll/poll01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/poll/poll02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ppoll/ppoll01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl06_execve | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/prctl/prctl09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pread/pread01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pread/pread01_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pread/pread02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pread/pread02_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pread/pread03 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/pread/pread03_64 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/preadv/preadv01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/preadv/preadv01_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/preadv/preadv02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv/preadv02_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv/preadv03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv/preadv03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv2/preadv201 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv2/preadv201_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv2/preadv202 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv2/preadv202_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv2/preadv203 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/preadv2/preadv203_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/profil/profil01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pselect/pselect01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pselect/pselect01_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pselect/pselect02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pselect/pselect02_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pselect/pselect03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pselect/pselect03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/make_syscall_list.sh | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ptrace/ptrace11 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pwrite/pwrite01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pwrite/pwrite01_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pwrite/pwrite02 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/pwrite/pwrite02_64 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/pwrite/pwrite03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pwrite/pwrite03_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pwrite/pwrite04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pwrite/pwrite04_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pwritev/pwritev01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pwritev/pwritev01_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/pwritev/pwritev02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pwritev/pwritev02_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pwritev/pwritev03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pwritev/pwritev03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pwritev2/pwritev201 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pwritev2/pwritev201_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pwritev2/pwritev202 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/pwritev2/pwritev202_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/quotactl/quotactl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/quotactl/quotactl02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/quotactl/quotactl03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/quotactl/quotactl04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/quotactl/quotactl05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/quotactl/quotactl06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/quotactl/quotactl07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/read/read01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/read/read02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/read/read03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/read/read04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/readahead/readahead01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/readahead/readahead02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/readdir/readdir01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/readdir/readdir21 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/readlink/readlink01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/readlink/readlink03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/readlinkat/readlinkat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/readlinkat/readlinkat02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/readv/readv01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/readv/readv02 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/readv/readv03 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/realpath/realpath01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/reboot/reboot01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/reboot/reboot02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/recv/recv01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/recvfrom/recvfrom01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/recvmmsg/recvmmsg01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/recvmsg/recvmsg01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/recvmsg/recvmsg02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/recvmsg/recvmsg03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/remap_file_pages/remap_file_pages01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/remap_file_pages/remap_file_pages02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/removexattr/removexattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/removexattr/removexattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/rename/rename02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/rename/rename03 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename04 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename05 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename06 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename07 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename10 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename11 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rename/rename13 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/rename/rename14 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/renameat/renameat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/renameat2/renameat201 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/renameat2/renameat202 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/request_key/request_key01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/request_key/request_key02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/request_key/request_key03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/request_key/request_key04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/request_key/request_key05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rmdir/rmdir01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/rmdir/rmdir02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rmdir/rmdir03 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/rt_sigaction/rt_sigaction01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/rt_sigaction/rt_sigaction02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rt_sigaction/rt_sigaction03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rt_sigprocmask/rt_sigprocmask01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/rt_sigprocmask/rt_sigprocmask02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rt_sigqueueinfo/rt_sigqueueinfo01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rt_sigsuspend/rt_sigsuspend01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/rt_sigtimedwait/rt_sigtimedwait01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sbrk/sbrk01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sbrk/sbrk02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sbrk/sbrk03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_get_priority_max/sched_get_priority_max01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_get_priority_max/sched_get_priority_max02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_get_priority_min/sched_get_priority_min01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_get_priority_min/sched_get_priority_min02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_getaffinity/sched_getaffinity01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_getattr/sched_getattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_getattr/sched_getattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_getparam/sched_getparam01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_getparam/sched_getparam03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_getscheduler/sched_getscheduler01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_getscheduler/sched_getscheduler02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_rr_get_interval/sched_rr_get_interval01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_rr_get_interval/sched_rr_get_interval02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_rr_get_interval/sched_rr_get_interval03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setaffinity/sched_setaffinity01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setattr/sched_setattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setparam/sched_setparam01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setparam/sched_setparam02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setparam/sched_setparam03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setparam/sched_setparam04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setparam/sched_setparam05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setscheduler/sched_setscheduler01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setscheduler/sched_setscheduler02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_setscheduler/sched_setscheduler03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sched_yield/sched_yield01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/select/select01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/select/select02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/select/select03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/select/select04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/send/send01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/send/send02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile02_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile04_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile05_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile06 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile06_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile07_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile08 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile08_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile09 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/sendfile/sendfile09_64 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/sendmmsg/sendmmsg01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendmmsg/sendmmsg02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sendmsg/sendmsg01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendmsg/sendmsg02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendmsg/sendmsg03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendto/sendto01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendto/sendto02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sendto/sendto03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/set_mempolicy/set_mempolicy01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/set_mempolicy/set_mempolicy02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/set_mempolicy/set_mempolicy03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/set_mempolicy/set_mempolicy04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/set_robust_list/set_robust_list01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/set_thread_area/set_thread_area01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/set_tid_address/set_tid_address01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setdomainname/setdomainname01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setdomainname/setdomainname02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setdomainname/setdomainname03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setegid/setegid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setegid/setegid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setfsgid/setfsgid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setfsgid/setfsgid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setfsgid/setfsgid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setfsgid/setfsgid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setfsgid/setfsgid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setfsgid/setfsgid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setfsuid/setfsuid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setfsuid/setfsuid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setfsuid/setfsuid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setfsuid/setfsuid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setfsuid/setfsuid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setfsuid/setfsuid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setfsuid/setfsuid04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setfsuid/setfsuid04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setgid/setgid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setgid/setgid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setgid/setgid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setgid/setgid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setgid/setgid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setgid/setgid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setgroups/setgroups01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setgroups/setgroups01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setgroups/setgroups02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setgroups/setgroups02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setgroups/setgroups03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setgroups/setgroups03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setgroups/setgroups04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setgroups/setgroups04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sethostname/sethostname01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sethostname/sethostname02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sethostname/sethostname03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setitimer/setitimer01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setitimer/setitimer02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setitimer/setitimer03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setns/setns01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setns/setns02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setpgid/setpgid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setpgid/setpgid02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setpgid/setpgid03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setpgid/setpgid03_child | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setpgrp/setpgrp01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setpgrp/setpgrp02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setpriority/setpriority01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setpriority/setpriority02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setregid/setregid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setregid/setregid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setregid/setregid02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setregid/setregid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setregid/setregid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setregid/setregid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setregid/setregid04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setregid/setregid04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresgid/setresgid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setresgid/setresgid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresgid/setresgid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setresgid/setresgid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresgid/setresgid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setresgid/setresgid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresgid/setresgid04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setresgid/setresgid04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setresuid/setresuid05_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid02_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid05_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid06 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid06_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setreuid/setreuid07_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setrlimit/setrlimit01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setrlimit/setrlimit02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setrlimit/setrlimit03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setrlimit/setrlimit04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setrlimit/setrlimit05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setrlimit/setrlimit06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setsid/setsid01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setsockopt/setsockopt01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setsockopt/setsockopt02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setsockopt/setsockopt03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setsockopt/setsockopt04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setsockopt/setsockopt05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setsockopt/setsockopt06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setsockopt/setsockopt07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/settimeofday/settimeofday01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/settimeofday/settimeofday02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setuid/setuid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setuid/setuid01_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setuid/setuid03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/setuid/setuid03_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setuid/setuid04 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/setuid/setuid04_16 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setxattr/setxattr01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setxattr/setxattr02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/setxattr/setxattr03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sgetmask/sgetmask01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sigaction/sigaction01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sigaction/sigaction02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sigaltstack/sigaltstack01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sigaltstack/sigaltstack02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sighold/sighold02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/signal/signal01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/signal/signal02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/signal/signal03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/signal/signal04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/signal/signal05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/signal/signal06 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/signalfd/signalfd01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/signalfd4/signalfd4_01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/signalfd4/signalfd4_02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sigpending/sigpending02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sigprocmask/sigprocmask01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sigrelse/sigrelse01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sigsuspend/sigsuspend01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sigtimedwait/sigtimedwait01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sigwait/sigwait01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sigwaitinfo/sigwaitinfo01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/socket/socket01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/socket/socket02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/socketcall/socketcall01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/socketcall/socketcall02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/socketcall/socketcall03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/socketpair/socketpair01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/socketpair/socketpair02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sockioctl/sockioctl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/splice/splice01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/splice/splice02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/splice/splice03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/splice/splice04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/splice/splice05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ssetmask/ssetmask01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/stat/stat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/stat/stat01_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/stat/stat02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/stat/stat02_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/stat/stat03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/stat/stat03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statfs/statfs01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/statfs/statfs01_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/statfs/statfs02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statfs/statfs02_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statfs/statfs03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statfs/statfs03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statvfs/statvfs01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/statvfs/statvfs02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statx/statx01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statx/statx02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statx/statx03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statx/statx04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statx/statx05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statx/statx06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/statx/statx07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/stime/stime01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/stime/stime02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/string/string01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/swapoff/swapoff01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/swapoff/swapoff02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/swapon/swapon01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/swapon/swapon02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/swapon/swapon03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/switch/endian_switch01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/symlink/symlink01 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/symlink/symlink02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/symlink/symlink03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/symlink/symlink04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/symlink/symlink05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/symlinkat/symlinkat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sync/sync01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sync_file_range/sync_file_range01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sync_file_range/sync_file_range02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syncfs/syncfs01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syscall/syscall01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sysconf/sysconf01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sysctl/sysctl01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysctl/sysctl03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysctl/sysctl04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysfs/sysfs01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysfs/sysfs02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysfs/sysfs03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysfs/sysfs04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysfs/sysfs05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysfs/sysfs06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysinfo/sysinfo01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/sysinfo/sysinfo02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/sysinfo/sysinfo03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog-lib.sh | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog09 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslog11 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/syslog/syslog12 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/syslog/syslogtst | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/tee/tee01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/tee/tee02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/tgkill/tgkill01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/tgkill/tgkill02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/tgkill/tgkill03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/time/time01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/timer_delete/timer_delete01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timer_delete/timer_delete02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timer_getoverrun/timer_getoverrun01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timer_gettime/timer_gettime01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timer_settime/timer_settime01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timer_settime/timer_settime02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timer_settime/timer_settime03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timerfd/timerfd01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timerfd/timerfd02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timerfd/timerfd03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timerfd/timerfd04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timerfd/timerfd_create01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timerfd/timerfd_gettime01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timerfd/timerfd_settime01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/timerfd/timerfd_settime02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/times/times01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/times/times03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/tkill/tkill01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/tkill/tkill02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/truncate/truncate02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/truncate/truncate02_64 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/truncate/truncate03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/truncate/truncate03_64 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ulimit/ulimit01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/umask/umask01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/umount/umount01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/umount/umount02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/umount/umount03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/umount2/umount2_01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/umount2/umount2_02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/umount2/umount2_03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/uname/uname01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/uname/uname02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/uname/uname04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/unlink/unlink05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/unlink/unlink07 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/unlink/unlink08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/unlinkat/unlinkat01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/unshare/unshare01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/unshare/unshare02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/userfaultfd/userfaultfd01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ustat/ustat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/ustat/ustat02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/utime/utime01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/utime/utime02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/utime/utime03 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/utime/utime04 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/utime/utime05 | 0 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/utime/utime06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/utimensat/utimensat01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/utimes/utimes01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/vfork/vfork01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/vfork/vfork02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/vhangup/vhangup01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/vhangup/vhangup02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/vmsplice/vmsplice01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/vmsplice/vmsplice02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/vmsplice/vmsplice03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/vmsplice/vmsplice04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/wait/wait01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/wait/wait02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/wait4/wait401 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/wait4/wait402 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/waitid/waitid01 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/waitid/waitid02 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid04 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid05 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid06 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid07 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid08 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid09 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid10 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid11 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid12 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/waitpid/waitpid13 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/write/write01 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/write/write02 | 1 | 1 | 1 |
| /ltp/testcases/kernel/syscalls/write/write03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/write/write04 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/write/write05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/writev/writev01 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/writev/writev02 | 1 | 1 | 0 |
| /ltp/testcases/kernel/syscalls/writev/writev03 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/writev/writev05 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/writev/writev06 | 0 | 0 | 0 |
| /ltp/testcases/kernel/syscalls/writev/writev07 | 0 | 0 | 0 |
